@@ -2,12 +2,12 @@
 
 # called by uscan with '--upstream-version' <version> <file>
 DIR=celestlab
-TAR=../scilab-celestlab_$2.orig.tar.gz
+TAR=../scilab-celestlab_$2.orig.tar.bz2
 
 # clean up the upstream tarball
 tar zxvf $3
 find $DIR -type f -exec chmod -x {} \;
-tar -c -z -f $TAR -X debian/orig-tar.exclude $DIR
+tar -c -j -f $TAR -X debian/orig-tar.exclude $DIR
 rm -rf $DIR $3
 
 # move to directory 'tarballs'
